<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Προβολέας εικόνων Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Έκδοση:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>εικόνα</translation>
    </message>
    <message>
        <source>images</source>
        <translation>εικόνες</translation>
    </message>
    <message>
        <source>album</source>
        <translation>άλμπουμ</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>άλμπουμ</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Διαχείριση συγχρονισμού</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Συγχρονίζει:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Νέο άλμπουμ</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Ανώνυμο</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Πρόσφατα εισαγόμενα</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Αγαπημένα</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Είστε σίγουρος πως θέλετε να σβήσετε το άλμπουμ;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Τα αγαπημένα μου</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Χρονοδιάγραμμα</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Μπορείτε να επιλέξετε φάκελο χρονισμού ή να σύρετε τις εικόνες στο χρονοδιαγραμμα</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Ανώνυμο</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Προβολέας εικόνων Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Είστε σίγουρος πως θέλετε να προσθέσετε τις εικόνες στο άλμπουμ;</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Συγχρονισμός και Δημιουργία</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Συγχρονισμός</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Είστε βέβαιοι πως θέλετε να το προσθέσετε στη λίστα συγχρονισμού και να δημιουργήσετε το λεύκωμα που ονομάζεται μετά από αυτό το φάκελο;</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Η εισαγωγή ολοκληρώθηκε με επιτυχία</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Η εισαγωγή απέτυχε</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να στείλετε τις φωτογραφίες στον κάδο ανακύκλωσης;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Πληροφοριες εικονας</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Αυτό το αρχείο περιέχει πολλές σελίδες, χρησιμοποιήστε το Evince για να δείτε όλες τις σελίδες.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>αφαίρεση από το άλμπουμ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερά </translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Μπορείτε να επιλέξετε φάκελο χρονισμού ή να σύρετε τις εικόνες στο χρονοδιαγραμμα</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Προσθήκη στο άλμπουμ</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Προσθήκη σε νέο άλμπουμ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Άνοιγμα τοποθεσίας</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Δεν έχετε δικαίωμα να δείτε αυτή την εικόνα</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Ημερομηνία επεξεργασίας</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Χρωματικός χώρος</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Λειτουργία έκθεσης</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Πρόγραμμα έκθεσης</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Χρόνος έκθεσης</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Φλάς</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Διάφραγμα</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Εστίαση</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Μέγιστο Διάφραγμα</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Λειτουργία μέτρησης</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Ισορροπία λευκού</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Ένταση φλάς</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Μοντέλο κάμερας</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Μοντέλο φακού</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>χωρίς κλίμακα</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Προσαρμογή σελίδας σε εικόνα</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Προσαρμογή εικόνας σε σελίδα</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Θέσε κλίμακα σε:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Χιλιοστά</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Εκατοστά</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Ίντσες</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Θέση εικόνας</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Κλιμάκωση</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Ρυθμίσεις εικόνας</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Περσίδες</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>πολυπλέκτης</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Κύλιση</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Επιλογή φακέλου</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>ο συγχρονισμός είναι σωστός για το φάκελο</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Προσθήκη φακέλου</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Διαχειριστής συγχρονισμού</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Η λίστα των φακέλων είναι άδεια</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Ακύρωση συγχρονισμού</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Η συσκευή έχει αφαιρεθεί</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ο φάκελος δεν υπάρχει</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Υπολογισμός...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Προβολή εικόνας</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Άλμπουμ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Τέλος παρουσίασης</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Αφαίρεση από το άλμπουμ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Προηγούμενο</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Προηγούμενη οθόνη </translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Επόμενη οθόνη</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>second</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image management</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 images</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manage sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Syncing: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recent imported</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>